<!DOCTYPE html>
<html>

<head>
    <meta charset="utf-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Arrnounced - Logs</title>
    <link rel="stylesheet" href="assets/bootstrap/css/bootstrap.min.css">
    <link rel="stylesheet" href="https://fonts.googleapis.com/css?family=Open+Sans:400italic,700italic,400,700">
    <link rel="stylesheet" href="assets/css/user.css">
</head>

<body>
    <nav class="navbar navbar-default" style="margin-bottom:0.5cm;">
        <div class="container-fluid">
            <div class="navbar-header"><a class="navbar-brand navbar-link" href="/"><i class="glyphicon glyphicon-transfer"></i>Announced</a>
                <button class="navbar-toggle collapsed" data-toggle="collapse" data-target="#navcol-1"><span class="sr-only">Toggle navigation</span><span class="icon-bar"></span><span class="icon-bar"></span><span class="icon-bar"></span></button>
            </div>
            <div class="collapse navbar-collapse" id="navcol-1">
                <ul class="nav navbar-nav navbar-right">
                    <li class="active" role="presentation"><a href="/logs">Logs </a></li>
                    {% if login_required %}
                    <li role="presentation"><a href="/logout">Logout </a></li>
                    {% endif %}
                </ul>
            </div>
        </div>
    </nav>
    <div class="container-fluid" style="padding-left:25px;padding-right:25px;">
        <div class="table-responsive">
            <table class="table table-striped table-bordered table-condensed">
                <thead>
                    <tr>
                        <th style="width:20%;">Time </th>
                        <th style="width:10%;">TAG </th>
                        <th>Message </th>
                    </tr>
                </thead>
                <tbody>
                    {% for log in logs %}
					<tr>
                        <td>{{ log['time'] }}</td>
                        <td>{{ log['tag'] }}</td>
                        <td>{{ log['msg'] }}</td>
                    </tr>
					{% endfor %}
                </tbody>
            </table>
        </div>
    </div>
    <script src="assets/js/jquery.min.js"></script>
    <script src="assets/bootstrap/js/bootstrap.min.js"></script>
    <script src="assets/js/common.js"></script>
    <script src="assets/js/logs.js"></script>
    <script src="assets/js/settings.js"></script>
</body>

</html>
